@@ -25,8 +25,6 @@ from datetime import datetime, timedelta
 import requests
 import logging
 from flask_cors import CORS, cross_origin
-# from flask_restful import Resource, Api
-# from flask_restful.utils import cors
 from flask import Flask, request, session, redirect, url_for
 from bscearth.utils.log import Log
 from database.db_common import get_current_running_exp, update_experiment_description_owner
@@ -36,7 +34,7 @@ from performance.performance_metrics import PerformanceMetrics
 from database.db_common import search_experiment_by_id
 from config.basicConfig import BasicConfig
 from builders.joblist_helper_builder import JobListHelperBuilder, JobListHelperDirector
-
+from multiprocessing import Manager
 
 JWT_SECRET = os.environ.get("SECRET_KEY")
 JWT_ALGORITHM = "HS256"
@@ -44,9 +42,10 @@ JWT_EXP_DELTA_SECONDS = 84000*5  # 5 days
 
 sys.path.insert(0, os.path.abspath('.'))
 
-
 app = Flask(__name__)
 
+D = Manager().dict()
+
 # CAS Stuff
 CAS_LOGIN_URL = os.environ.get("CAS_LOGIN_URL") # 'https://cas.bsc.es/cas/login'
 CAS_VERIFY_URL = os.environ.get("CAS_VERIFY_URL") # 'https://cas.bsc.es/cas/serviceValidate'
@@ -56,6 +55,12 @@ gunicorn_logger = logging.getLogger('gunicorn.error')
 app.logger.handlers = gunicorn_logger.handlers
 app.logger.setLevel(gunicorn_logger.level)
 
+requests.packages.urllib3.util.ssl_.DEFAULT_CIPHERS += 'HIGH:!DH:!aNULL'
+try:
+    requests.packages.urllib3.contrib.pyopenssl.DEFAULT_SSL_CIPHER_LIST += 'HIGH:!DH:!aNULL'
+except AttributeError:
+    # no pyopenssl support used / needed / available
+    pass
 
 # CAS Login
 @app.route('/login')
@@ -71,18 +76,19 @@ def login():
             is_allowed = True
     if is_allowed == False:
         return {'authenticated': False, 'user': None, 'token': None, 'message': "Your client is not authorized for this operation. The API admin needs to add your URL to the list of allowed clients."}
-    
+
     target_service = "{}{}/login".format(referrer, environment)
     if not ticket:
-        route_to_request_ticket = "{}?service={}".format(CAS_LOGIN_URL, target_service)                
+        route_to_request_ticket = "{}?service={}".format(CAS_LOGIN_URL, target_service)
+        app.logger.info("Redirected to: " + str(route_to_request_ticket))
         return redirect(route_to_request_ticket)
-    environment = environment if environment is not None else "autosubmitapp" # can be used to target the test environment    
-    cas_verify_ticket_route = CAS_VERIFY_URL + '?service=' + target_service + '&ticket=' + ticket    
+    environment = environment if environment is not None else "autosubmitapp" # can be used to target the test environment
+    cas_verify_ticket_route = CAS_VERIFY_URL + '?service=' + target_service + '&ticket=' + ticket
     response = requests.get(cas_verify_ticket_route)
     user = None
     if response:
         user = Utiles.get_cas_user_from_xml(response.content)
-    app.logger.info('CAS verify ticket response: user %s', user)    
+    app.logger.info('CAS verify ticket response: user %s', user)
     if not user:
         return {'authenticated': False, 'user': None, 'token': None, 'message': "Can't verify user."}
     else:  # Login successful
@@ -112,7 +118,7 @@ def update_description():
         jwt_token = jwt.decode(current_token, JWT_SECRET, JWT_ALGORITHM)
     except jwt.ExpiredSignatureError:
         jwt_token = {"user_id": None}
-    except Exception as exp:            
+    except Exception as exp:
         jwt_token = {"user_id": None}
     valid_user = jwt_token.get("user_id", None)
     app.logger.info('UDESC|RECEIVED|')
@@ -147,7 +153,7 @@ def test_token():
 
 @app.route('/cconfig/<string:expid>', methods=['GET'])
 @cross_origin(expose_headers="Authorization")
-def get_current_configuration(expid):            
+def get_current_configuration(expid):
     start_time = time.time()
     current_token = request.headers.get("Authorization")
     try:
@@ -156,7 +162,7 @@ def get_current_configuration(expid):
         jwt_token = {"user_id": None}
     valid_user = jwt_token.get("user_id", None)
     app.logger.info('CCONFIG|RECEIVED|' + str(expid))
-    result = CommonRequests.get_current_configuration_by_expid(expid, valid_user)
+    result = CommonRequests.get_current_configuration_by_expid(expid, valid_user, app.logger)
     app.logger.info('CCONFIG|RTIME|' + str(expid) + "|" + str(time.time() - start_time))
     return result
 
@@ -196,7 +202,7 @@ def search_owner(owner, exptype=None, onlyactive=None):
 @app.route('/search/<string:expid>', methods=['GET'])
 def search_expid(expid, exptype=None, onlyactive=None):
     start_time = time.time()
-    app.logger.info('SEARCH|RECEIVED|' + str(expid) + "|" + str(exptype) + "|" + str(onlyactive))    
+    app.logger.info('SEARCH|RECEIVED|' + str(expid) + "|" + str(exptype) + "|" + str(onlyactive))
     result = search_experiment_by_id(expid, owner=None, typeExp=exptype, onlyActive=onlyactive)
     app.logger.info('SEARCH|RTIME|' + str(expid) + "|" + str(exptype) + "|" + str(onlyactive) + "|" + str(time.time() - start_time))
     return result
@@ -210,6 +216,7 @@ def search_running():
     if 'username' in session:
         print("USER {}".format(session['username']))
     start_time = time.time()
+    app.logger.info("Active proceses: " + str(D))
     app.logger.info('RUN|RECEIVED|')
     #app.logger.info("Received Currently Running query ")
     result = get_current_running_exp()
@@ -250,19 +257,61 @@ def get_log_running(expid):
 @app.route('/summary/<string:expid>', methods=['GET'])
 def get_expsummary(expid):
     start_time = time.time()
+    user = request.args.get("loggedUser", default="null", type=str)
     app.logger.info('SUMMARY|RECEIVED|' + str(expid))
+    if user != "null": D[os.getpid()] = [user, "summary", True]
     result = CommonRequests.get_experiment_summary(expid)
+    app.logger.info('Process: ' + str(os.getpid()) + " workers: " + str(D))
     app.logger.info('SUMMARY|RTIME|' + str(expid) + "|" + str(time.time() - start_time))
+    if user != "null": D[os.getpid()] = [user, "summary", False]
+    if user != "null": D.pop(os.getpid(), None)
     return result
 
 
+@app.route('/shutdown/<string:route>')
+def shutdown(route):
+    """
+    This function is invoked from the frontend (AS-GUI) to kill workers that are no longer needed.
+    This call is common in heavy parts of the GUI such as the Tree and Graph generation or Summaries fetching.
+    """
+    start_time = time.time()
+
+    try:
+        user = request.args.get("loggedUser", default="null", type=str)
+        expid = request.args.get("expid", default="null", type=str)
+    except Exception as exp:
+        app.logger.info("Bad parameters for user and expid in route.")
+
+    if user != "null":
+        app.logger.info('SHUTDOWN|RECEIVED for route: ' + route + " user: " + user + " expid: " + expid)
+        try:
+            # app.logger.info("user: " + user)
+            # app.logger.info("expid: " + expid)
+            app.logger.info("Workers before: " + str(D))
+            for k,v in D.items():
+                if v[0] == user and v[1] == route and v[-1] == True:
+                    if v[2] == expid:
+                        D[k] = [user, route, expid, False]
+                    else:
+                        D[k] = [user, route, False]
+                    D.pop(k, None)
+                    # reboot the worker
+                    os.system('kill -HUP ' + str(k))
+                    app.logger.info("killed worker " + str(k))
+            app.logger.info("Workers now: " + str(D))
+        except Exception as exp:
+            app.logger.info("[CRITICAL] Could not shutdown process " + expid + " by user \"" + user + "\"")
+    app.logger.info('SHUTDOWN|DONE|RTIME' + "|" + str(time.time() - start_time))
+    return ""
+
+
 @app.route('/performance/<string:expid>', methods=['GET'])
 def get_exp_performance(expid):
     start_time = time.time()
     app.logger.info('PRF|RECEIVED|' + str(expid))
     result = {}
-    try:    
-        result = PerformanceMetrics(expid, JobListHelperDirector(JobListHelperBuilder(expid)).build_job_list_helper()).to_json() 
+    try:
+        result = PerformanceMetrics(expid, JobListHelperDirector(JobListHelperBuilder(expid)).build_job_list_helper()).to_json()
     except Exception as exp:
         result = {"SYPD": None,
             "ASYPD": None,
@@ -274,7 +323,7 @@ def get_exp_performance(expid):
             "error": True,
             "error_message": str(exp),
             "warnings_job_data": [],
-            }
+        }
     app.logger.info('PRF|RTIME|' + str(expid) + "|" + str(time.time() - start_time))
     return result
 
@@ -282,18 +331,32 @@ def get_exp_performance(expid):
 @app.route('/graph/<string:expid>/<string:layout>/<string:grouped>', methods=['GET'])
 def get_list_format(expid, layout='standard', grouped='none'):
     start_time = time.time()
+    user = request.args.get("loggedUser", default="null", type=str)
+    # app.logger.info("user: " + user)
+    # app.logger.info("expid: " + expid)
     app.logger.info('GRAPH|RECEIVED|' + str(expid) + "~" + str(grouped) + "~" + str(layout))
-    result = CommonRequests.get_experiment_graph(expid, layout, grouped)
+    if user != "null": D[os.getpid()] = [user, "graph", expid, True]
+    result = CommonRequests.get_experiment_graph(expid, app.logger, layout, grouped)
+    app.logger.info('Process: ' + str(os.getpid()) + " graph workers: " + str(D))
     app.logger.info('GRAPH|RTIME|' + str(expid) + "|" + str(time.time() - start_time))
+    if user != "null": D[os.getpid()] = [user, "graph", expid, False]
+    if user != "null": D.pop(os.getpid(), None)
     return result
 
 
 @app.route('/tree/<string:expid>', methods=['GET'])
 def get_exp_tree(expid):
     start_time = time.time()
-    app.logger.info('TREE|RECEIVED|' + str(expid))    
-    result = CommonRequests.get_experiment_tree_structured(expid)
+    user = request.args.get("loggedUser", default="null", type=str)
+    # app.logger.info("user: " + user)
+    # app.logger.info("expid: " + expid)
+    app.logger.info('TREE|RECEIVED|' + str(expid))
+    if user != "null": D[os.getpid()] = [user, "tree", expid, True]
+    result = CommonRequests.get_experiment_tree_structured(expid, app.logger)
+    app.logger.info('Process: ' + str(os.getpid()) + " tree workers: " + str(D))
     app.logger.info('TREE|RTIME|' + str(expid) + "|" + str(time.time() - start_time))
+    if user != "null": D[os.getpid()] = [user, "tree", expid, False]
+    if user != "null": D.pop(os.getpid(), None)
     return result
 
 
@@ -312,7 +375,7 @@ def get_experiment_running(expid):
     Finds log and gets the last 150 lines
     """
     start_time = time.time()
-    app.logger.info('LOG|RECEIVED|' + str(expid))    
+    app.logger.info('LOG|RECEIVED|' + str(expid))
     result = CommonRequests.get_experiment_log_last_lines(expid)
     app.logger.info('LOG|RTIME|' + str(expid) + "|" + str(time.time() - start_time))
     return result
@@ -324,7 +387,7 @@ def get_job_log_from_path(logfile):
     Get log from path
     """
     expid = logfile.split('_') if logfile is not None else ""
-    expid = expid[0] if len(expid) > 0 else ""    
+    expid = expid[0] if len(expid) > 0 else ""
     start_time = time.time()
     app.logger.info('JOBLOG|RECEIVED|{0}'.format(expid))
     result = CommonRequests.get_job_log(expid, logfile)
@@ -335,7 +398,7 @@ def get_job_log_from_path(logfile):
 @app.route('/pklinfo/<string:expid>/<string:timeStamp>', methods=['GET'])
 def get_experiment_pklinfo(expid, timeStamp):
     start_time = time.time()
-    app.logger.info('GPKL|RECEIVED|' + str(expid) + "~" + str(timeStamp))    
+    app.logger.info('GPKL|RECEIVED|' + str(expid) + "~" + str(timeStamp))
     result = CommonRequests.get_experiment_pkl(expid)
     app.logger.info('GPKL|RTIME|' + str(expid) + "|" + str(time.time() - start_time))
     return result
@@ -371,7 +434,7 @@ def get_exp_job_history(expid, jobname):
 @app.route('/rundetail/<string:expid>/<string:runid>')
 def get_experiment_run_job_detail(expid, runid):
     start_time = time.time()
-    app.logger.info('RUNDETAIL|RECEIVED|' + str(expid) + "~" + str(runid))    
+    app.logger.info('RUNDETAIL|RECEIVED|' + str(expid) + "~" + str(runid))
     result = CommonRequests.get_experiment_tree_rundetail(expid, runid)
     app.logger.info('RUNDETAIL|RTIME|' + str(expid) + "|" + str(time.time() - start_time))
     return result
@@ -384,4 +447,3 @@ def get_file_status():
     result = CommonRequests.get_last_test_archive_status()
     app.logger.info('FSTATUS|RTIME|' + str(time.time() - start_time))
     return result
-
